import sys
import itertools

def manhattan_distance(p1, p2):
    return abs(p1[0] - p2[0]) + abs(p1[1] - p2[1])

def tsp_distances(points):
    n = len(points)
    dist = [[0] * n for _ in range(n)]
    for i in range(n):
        for j in range(n):
            dist[i][j] = manhattan_distance(points[i], points[j])
    return dist

def tsp_dp(points):
    n = len(points)
    dist = tsp_distances(points)
    
    # Динамическое программирование с битовой маской
    dp = [[float('inf')] * n for _ in range(1 << n)]
    for i in range(n):
        dp[1 << i][i] = 0  # Начинаем с каждой точки

    for mask in range(1 << n):
        for u in range(n):
            if (mask & (1 << u)) == 0:
                continue  # Точка u не включена в маску
            for v in range(n):
                if (mask & (1 << v)) != 0:
                    continue  # Точка v уже включена в маску
                new_mask = mask | (1 << v)
                dp[new_mask][v] = min(dp[new_mask][v], dp[mask][u] + dist[u][v])

    # Закрываем цикл, возвращаясь в стартовую точку
    min_cost = float('inf')
    for i in range(n):
        min_cost = min(min_cost, dp[(1 << n) - 1][i] + dist[i][0])  # Возврат в стартовую точку

    return min_cost

# Ввод данных
n = int(input().strip())
points = [tuple(map(int, input().strip().split())) for _ in range(n)]

# Решение задачи TSP
result = tsp_dp(points)

# Вывод результата
print(f"{result:.6f}")
